{% load i18n sizeformat parse_date %}
{% load url from future %}

<div class="info row detail">
	<hr class="header_rule">
	<dl>
		<dt>{% trans "Name" %}</dt>
		<dd>{{ scnode.name|default:_("-") }}</dd>

		<dt>{% trans "Description" %}</dt>
		<dd>{{ scnode.description|default:_("-") }}</dd>

		<dt>{% trans "ID" %}</dt>
		<dd>{{ scnode.id }} </dd>
		
        <dt>{% trans "Service Profile" %}</dt>
	<dd><a href="{% url 'horizon:project:network_services:service_profile_details' sp_id=scnode.service_profile_id %}">{{ scnode.service_profile_id }}</a></dd>

		<dt>{% trans "Config" %}</dt>
		<dd>
                    <div style ="white-space:pre">{{ scnode.config }}</div>
               </dd>
	</dl>
</div>                   
